'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Sentry = require('@sentry/browser');
var rrweb = require('rrweb');
var utils = require('@sentry/utils');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var Sentry__namespace = /*#__PURE__*/_interopNamespace(Sentry);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

function __spreadArray(to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
}

var _a;
// Map entryType -> function to normalize data for event
var ENTRY_TYPES = (_a = {
        resource: createResourceEntry,
        paint: createPaintEntry,
        navigation: createNavigationEntry
    },
    _a['largest-contentful-paint'] = createLargestContentfulPaint,
    _a);
function createPerformanceEntries(entries) {
    return entries.map(createPerformanceEntry).filter(Boolean);
}
function createPerformanceEntry(entry) {
    if (ENTRY_TYPES[entry.entryType] === undefined) {
        return null;
    }
    return ENTRY_TYPES[entry.entryType](entry);
}
function getAbsoluteTime(time) {
    return (window.performance.timeOrigin + time) / 1000;
}
function createPaintEntry(entry) {
    var duration = entry.duration, entryType = entry.entryType, name = entry.name, startTime = entry.startTime;
    var start = getAbsoluteTime(startTime);
    return {
        type: entryType,
        name: name,
        start: start,
        end: start + duration,
    };
}
function createNavigationEntry(entry) {
    // TODO: There looks to be some more interesting bits in here (domComplete, domContentLoaded)
    var entryType = entry.entryType, name = entry.name, domComplete = entry.domComplete, startTime = entry.startTime, transferSize = entry.transferSize, type = entry.type;
    return {
        type: "".concat(entryType, ".").concat(type),
        start: getAbsoluteTime(startTime),
        end: getAbsoluteTime(domComplete),
        name: name,
        data: {
            size: transferSize,
        },
    };
}
function createResourceEntry(entry) {
    var entryType = entry.entryType, initiatorType = entry.initiatorType, name = entry.name, responseEnd = entry.responseEnd, startTime = entry.startTime, transferSize = entry.transferSize;
    return {
        type: "".concat(entryType, ".").concat(initiatorType),
        start: getAbsoluteTime(startTime),
        end: getAbsoluteTime(responseEnd),
        name: name,
        data: {
            size: transferSize,
        },
    };
}
function createLargestContentfulPaint(entry) {
    var duration = entry.duration, entryType = entry.entryType, startTime = entry.startTime, size = entry.size;
    var start = getAbsoluteTime(startTime);
    return {
        type: entryType,
        name: entryType,
        start: start,
        end: start + duration,
        data: {
            size: size,
        },
    };
}

var REPLAY_SESSION_KEY = 'sentryReplaySession';
var ROOT_REPLAY_NAME = 'sentry-replay';
var REPLAY_EVENT_NAME = 'sentry-replay-event';
// Grace period to keep a session when a user changes tabs or hides window
var VISIBILITY_CHANGE_TIMEOUT = 60000; // 1 minute
// The idle limit for a session
var SESSION_IDLE_DURATION = 900000; // 15 minutes

/**
 * Given an initial timestamp and an expiry duration, checks to see if current
 * time should be considered as expired.
 */
function isExpired(initialTime, expiry, targetTime) {
    if (targetTime === void 0) { targetTime = +new Date(); }
    // Always expired if < 0
    if (expiry < 0) {
        return true;
    }
    // Never expires if == 0
    if (expiry === 0) {
        return false;
    }
    return initialTime + expiry <= targetTime;
}

/**
 * Checks to see if session is expired
 */
function isSessionExpired(session, expiry, targetTime) {
    if (targetTime === void 0) { targetTime = +new Date(); }
    return isExpired(session.lastActivity, expiry, targetTime);
}

function wrapLogger(logFn) {
    return function wrappedLog() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        {
            return;
        }
    };
}
var logger = __assign(__assign({}, utils.logger), { error: wrapLogger(utils.logger.error), warn: wrapLogger(utils.logger.warn), log: wrapLogger(utils.logger.log) });

function saveSession(session) {
    var hasSessionStorage = 'sessionStorage' in window;
    if (!hasSessionStorage) {
        return;
    }
    try {
        window.sessionStorage.setItem(REPLAY_SESSION_KEY, JSON.stringify(session));
    }
    catch (_a) {
        // this shouldn't happen
    }
}

/**
 * Create a new session, which in its current implementation is a Sentry event
 * that all replays will be saved to as attachments. Currently, we only expect
 * one of these Sentry events per "replay session".
 */
function createSession(_a) {
    var _b = _a.stickySession, stickySession = _b === void 0 ? false : _b;
    var currentDate = new Date().getTime();
    // Create root replay event, this is where attachments will be saved
    var transaction = Sentry__namespace.getCurrentHub().startTransaction({
        name: ROOT_REPLAY_NAME,
        tags: {
            isReplayRoot: 'yes',
        },
    });
    // We have to finish the transaction to get an event ID to be able to
    // upload an attachment for that event
    // @ts-expect-error This returns an eventId (string), but is not typed as such
    var id = transaction.finish();
    logger.log("Creating new session: ".concat(id));
    var session = {
        id: id,
        spanId: transaction.spanId,
        traceId: transaction.traceId,
        started: currentDate,
        lastActivity: currentDate,
    };
    if (stickySession) {
        saveSession(session);
    }
    return session;
}

function fetchSession() {
    var hasSessionStorage = 'sessionStorage' in window;
    if (!hasSessionStorage) {
        return null;
    }
    try {
        return JSON.parse(window.sessionStorage.getItem(REPLAY_SESSION_KEY));
    }
    catch (_a) {
        return null;
    }
}

/**
 * Get or create a session
 */
function getSession(_a) {
    var expiry = _a.expiry, stickySession = _a.stickySession;
    var session = stickySession && fetchSession();
    if (session) {
        // If there is a session, check if it is valid (e.g. "last activity" time should be within the "session idle time")
        // TODO: We should probably set a max age on this as well
        var isExpired = isSessionExpired(session, expiry);
        if (!isExpired) {
            logger.log("Using existing session: ".concat(session.id));
            return session;
        }
        else {
            logger.log("Session has expired");
        }
        // Otherwise continue to create a new session
    }
    var newSession = createSession({ stickySession: stickySession });
    return newSession;
}

function updateSessionActivity(_a) {
    var stickySession = _a.stickySession;
    // Nothing to do if there are no sticky sessions
    if (!stickySession) {
        return;
    }
    var existingSession = fetchSession();
    // If user manually deleted from session storage, create a new session
    if (!existingSession) {
        // TBD: There was an issue here where sessions weren't saving and this
        // caused lots of transactions to be created
        return createSession({ stickySession: stickySession });
    }
    var newSession = __assign(__assign({}, existingSession), { lastActivity: new Date().getTime() });
    saveSession(newSession);
    return newSession;
}

var SentryReplay = /** @class */ (function () {
    function SentryReplay(_a) {
        if (_a === void 0) { _a = {}; }
        var _this = this;
        var _b = _a.uploadMinDelay, uploadMinDelay = _b === void 0 ? 5000 : _b, _c = _a.uploadMaxDelay, uploadMaxDelay = _c === void 0 ? 15000 : _c, _d = _a.stickySession, stickySession = _d === void 0 ? false : _d, // TBD: Making this opt-in for now
        _e = _a.rrwebConfig, // TBD: Making this opt-in for now
        _f = _e === void 0 ? {} : _e, _g = _f.maskAllInputs, maskAllInputs = _g === void 0 ? true : _g, rrwebRecordOptions = __rest(_f, ["maskAllInputs"]);
        /**
         * @inheritDoc
         */
        this.name = SentryReplay.id;
        /**
         * Buffer of rrweb events that will be serialized as JSON and saved as an attachment to a Sentry event
         */
        this.events = [];
        this.performanceEvents = [];
        /**
         * The timestamp of the first event since the last flush.
         * This is used to determine if the maximum allowed time has passed before we should flush events again.
         */
        this.initialEventTimestampSinceFlush = null;
        this.performanceObserver = null;
        /**
         * Keep a list of performance entries that will be sent with a replay
         */
        this.handlePerformanceObserver = function (list
        // observer: PerformanceObserver
        ) {
            _this.performanceEvents = __spreadArray(__spreadArray([], _this.performanceEvents, true), list.getEntries(), true);
        };
        /**
         * Handle when visibility of the page changes. (e.g. new tab is opened)
         */
        this.handleVisibilityChange = function () {
            var isExpired = isSessionExpired(_this.session, VISIBILITY_CHANGE_TIMEOUT);
            if (isExpired) {
                if (document.visibilityState === 'visible') {
                    // If the user has come back to the page within VISIBILITY_CHANGE_TIMEOUT
                    // ms, we will re-use the existing session, otherwise create a new
                    // session
                    logger.log('Document has become active, but session has expired');
                    _this.triggerFullSnapshot();
                }
                // We definitely want to return if visibilityState is "visible", and I
                // think we also want to do the same when "hidden", as there shouldn't be
                // any action to take if user has gone idle for a long period and then
                // comes back to hide the tab. We don't trigger a full snapshot because
                // we don't want to start a new session as they immediately have hidden
                // the tab.
                return;
            }
            // Otherwise if session is not expired...
            // Update with current timestamp as the last session activity
            // Only updating session on visibility change to be conservative about
            // writing to session storage. This could be changed in the future.
            updateSessionActivity({
                stickySession: _this.options.stickySession,
            });
            // Send replay when the page/tab becomes hidden. There is no reason to send
            // replay if it becomes visible, since no actions we care about were done
            // while it was hidden
            if (document.visibilityState !== 'visible') {
                _this.finishReplayEvent();
            }
        };
        this.rrwebRecordOptions = __assign({ maskAllInputs: maskAllInputs }, rrwebRecordOptions);
        this.options = { uploadMinDelay: uploadMinDelay, uploadMaxDelay: uploadMaxDelay, stickySession: stickySession };
        this.events = [];
    }
    SentryReplay.attachmentUrlFromDsn = function (dsn, eventId) {
        var host = dsn.host, path = dsn.path, projectId = dsn.projectId, port = dsn.port, protocol = dsn.protocol, user = dsn.user;
        return "".concat(protocol, "://").concat(host).concat(port !== '' ? ":".concat(port) : '').concat(path !== '' ? "/".concat(path) : '', "/api/").concat(projectId, "/events/").concat(eventId, "/attachments/?sentry_key=").concat(user, "&sentry_version=7&sentry_client=replay");
    };
    Object.defineProperty(SentryReplay.prototype, "instance", {
        /**
         * Get integration's instance on the current hub
         */
        get: function () {
            return Sentry__namespace.getCurrentHub().getIntegration(SentryReplay);
        },
        enumerable: false,
        configurable: true
    });
    SentryReplay.prototype.setupOnce = function () {
        var _this = this;
        /**
         * Because we create a transaction in `setupOnce`, we can potentially create a
         * transaction before some native SDK integrations have run and applied their
         * own global event processor. An example is:
         * https://github.com/getsentry/sentry-javascript/blob/b47ceafbdac7f8b99093ce6023726ad4687edc48/packages/browser/src/integrations/useragent.ts
         *
         * So we do this as a workaround to wait for other global event processors to finish
         */
        setImmediate(function () { return _this.setup(); });
    };
    SentryReplay.prototype.setup = function () {
        var _this = this;
        this.loadSession({ expiry: SESSION_IDLE_DURATION });
        // If there is no session, then something bad has happened - can't continue
        if (!this.session) {
            throw new Error('Invalid session');
        }
        // Tag all (non replay) events that get sent to Sentry with the current
        // replay ID so that we can reference them later in the UI
        Sentry__namespace.addGlobalEventProcessor(function (event) {
            // Do not apply replayId to the root transaction
            if (event.transaction === ROOT_REPLAY_NAME) {
                return event;
            }
            event.tags = __assign(__assign({}, event.tags), { replayId: _this.session.id });
            return event;
        });
        rrweb.record(__assign(__assign({}, this.rrwebRecordOptions), { emit: function (event, isCheckout) {
                // We want to batch uploads of replay events. Save events only if
                // `<uploadMinDelay>` milliseconds have elapsed since the last event
                // *OR* if `<uploadMaxDelay>` milliseconds have elapsed.
                var now = new Date().getTime();
                // Timestamp of the first replay event since the last flush, this gets
                // reset when we finish the replay event
                if (!_this.initialEventTimestampSinceFlush) {
                    _this.initialEventTimestampSinceFlush = now;
                }
                var uploadMaxDelayExceeded = isExpired(_this.initialEventTimestampSinceFlush, _this.options.uploadMaxDelay, now);
                // Do not finish the replay event if we receive a new replay event
                // unless `<uploadMaxDelay>` ms have elapsed since the last time we
                // finished the replay
                if (_this.timeout && !uploadMaxDelayExceeded) {
                    window.clearTimeout(_this.timeout);
                }
                // We need to clear existing events on a checkout, otherwise they are
                // incremental event updates and should be appended
                if (isCheckout) {
                    _this.events = [event];
                }
                else {
                    _this.events.push(event);
                }
                // This event type is a fullsnapshot, we should save immediately when this occurs
                // See https://github.com/rrweb-io/rrweb/blob/d8f9290ca496712aa1e7d472549480c4e7876594/packages/rrweb/src/types.ts#L16
                if (event.type === 2) {
                    // A fullsnapshot happens on initial load and if we need to start a
                    // new replay due to idle timeout. In the later case we will need to
                    // create a new session before finishing the replay.
                    _this.loadSession({ expiry: SESSION_IDLE_DURATION });
                    _this.finishReplayEvent();
                    return;
                }
                // Set timer to finish replay event and send replay attachment to
                // Sentry. Will be cancelled if an event happens before `uploadMinDelay`
                // elapses.
                _this.timeout = window.setTimeout(function () {
                    logger.log('rrweb timeout hit, finishing replay event');
                    _this.finishReplayEvent();
                }, _this.options.uploadMinDelay);
            } }));
        this.addListeners();
        // XXX: this needs to be in `setupOnce` vs `constructor`, otherwise SDK is
        // not fully initialized and the event will not get properly sent to Sentry
        this.createReplayEvent();
    };
    /**
     * Loads a session from storage, or creates a new one
     */
    SentryReplay.prototype.loadSession = function (_a) {
        var expiry = _a.expiry;
        this.session = getSession({
            expiry: expiry,
            stickySession: this.options.stickySession,
        });
    };
    SentryReplay.prototype.addListeners = function () {
        document.addEventListener('visibilitychange', this.handleVisibilityChange);
        if ('PerformanceObserver' in window) {
            this.performanceObserver = new PerformanceObserver(this.handlePerformanceObserver);
            // Observe everything for now
            this.performanceObserver.observe({
                entryTypes: __spreadArray([], PerformanceObserver.supportedEntryTypes, true),
            });
        }
    };
    /**
     * Trigger rrweb to take a full snapshot which will cause this plugin to
     * create a new Replay event.
     */
    SentryReplay.prototype.triggerFullSnapshot = function () {
        logger.log('Taking full rrweb snapshot');
        rrweb.record.takeFullSnapshot(true);
    };
    /**
     * This is our pseudo replay event disguised as a transaction. It will be
     * used to store performance entries and breadcrumbs for every incremental
     * replay event.
     **/
    SentryReplay.prototype.createReplayEvent = function () {
        var _this = this;
        logger.log('CreateReplayEvent rootReplayId', this.session.id);
        this.replayEvent = Sentry__namespace.startTransaction({
            name: REPLAY_EVENT_NAME,
            parentSpanId: this.session.spanId,
            traceId: this.session.traceId,
            tags: {
                replayId: this.session.id,
            },
        });
        Sentry__namespace.configureScope(function (scope) { return scope.setSpan(_this.replayEvent); });
        return this.replayEvent;
    };
    /**
     * Create a span for each performance entry. The parent transaction is `this.replayEvent`.
     */
    SentryReplay.prototype.createPerformanceSpans = function (entries) {
        var _this = this;
        entries.forEach(function (_a) {
            var _b;
            var type = _a.type, start = _a.start, end = _a.end, name = _a.name, data = _a.data;
            var span = (_b = _this.replayEvent) === null || _b === void 0 ? void 0 : _b.startChild({
                op: type,
                description: name,
                startTimestamp: start,
                data: data,
            });
            span.finish(end);
        });
    };
    /**
     * Observed performance events are added to `this.performanceEvents`. These
     * are included in the replay event before it is finished and sent to Sentry.
     */
    SentryReplay.prototype.addPerformanceEntries = function () {
        // Copy and reset entries before processing
        var entries = __spreadArray([], this.performanceEvents, true);
        this.performanceEvents = [];
        // Parse the entries
        var entryEvents = createPerformanceEntries(entries);
        // This current implementation is to create spans on the transaction referenced in `this.replayEvent`
        this.createPerformanceSpans(entryEvents);
    };
    SentryReplay.prototype.finishReplayEvent = function () {
        // if (!this.instance) return;
        var _a;
        // Ensure that our existing session has not expired
        var isExpired = isSessionExpired(this.session, SESSION_IDLE_DURATION);
        if (isExpired) {
            // TBD: If it is expired, we do not send any events...we could send to
            // the expired session, but not sure if that's great
            console.error(new Error('Attempting to finish replay event after session expired.'));
            return;
        }
        if (!this.session.id) {
            console.error(new Error('[Sentry]: No transaction, no replay'));
            return;
        }
        this.sendReplay(this.session.id);
        this.initialEventTimestampSinceFlush = null;
        // TBD: Alternatively we could update this after every rrweb event
        this.session.lastActivity = new Date().getTime();
        // include performance entries
        this.addPerformanceEntries();
        // Close out existing replay event and create a new one
        (_a = this.replayEvent) === null || _a === void 0 ? void 0 : _a.setStatus('ok').finish();
        this.createReplayEvent();
    };
    /**
     * Determine if there is browser support for `navigator.sendBeacon`
     */
    SentryReplay.prototype.hasSendBeacon = function () {
        return 'navigator' in window && 'sendBeacon' in window.navigator;
    };
    /**
     * Send replay attachment using either `sendBeacon()` or `fetch()`
     */
    SentryReplay.prototype.sendReplayRequest = function (endpoint, events) {
        return __awaiter(this, void 0, void 0, function () {
            var stringifiedPayload, formData, ex_1;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        stringifiedPayload = JSON.stringify({ events: events });
                        formData = new FormData();
                        formData.append('rrweb', new Blob([stringifiedPayload], {
                            type: 'application/json',
                        }), "rrweb-".concat(new Date().getTime(), ".json"));
                        // If sendBeacon is supported and payload is smol enough...
                        if (this.hasSendBeacon() && stringifiedPayload.length <= 65536) {
                            logger.log("uploading attachment via sendBeacon()");
                            window.navigator.sendBeacon(endpoint, formData);
                            return [2 /*return*/];
                        }
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        logger.log("uploading attachment via fetch()");
                        // Otherwise use `fetch`, which *WILL* get cancelled on page reloads/unloads
                        return [4 /*yield*/, fetch(endpoint, {
                                method: 'POST',
                                body: formData,
                            })];
                    case 2:
                        // Otherwise use `fetch`, which *WILL* get cancelled on page reloads/unloads
                        _a.sent();
                        return [3 /*break*/, 4];
                    case 3:
                        ex_1 = _a.sent();
                        // we have to catch this otherwise it throws an infinite loop in Sentry
                        console.error(ex_1);
                        return [3 /*break*/, 4];
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Finalize and send the current replay event to Sentry
     */
    SentryReplay.prototype.sendReplay = function (eventId) {
        return __awaiter(this, void 0, void 0, function () {
            var client, endpoint, ex_2;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 2, , 3]);
                        // short circuit if theres no events to replay
                        if (!this.events.length)
                            return [2 /*return*/];
                        client = Sentry__namespace.getCurrentHub().getClient();
                        endpoint = SentryReplay.attachmentUrlFromDsn(client.getDsn(), eventId);
                        return [4 /*yield*/, this.sendReplayRequest(endpoint, this.events)];
                    case 1:
                        _a.sent();
                        this.events = [];
                        return [2 /*return*/, true];
                    case 2:
                        ex_2 = _a.sent();
                        console.error(ex_2);
                        return [2 /*return*/, false];
                    case 3: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @inheritDoc
     */
    SentryReplay.id = 'Replay';
    return SentryReplay;
}());

exports.SentryReplay = SentryReplay;
//# sourceMappingURL=index.js.map
